/*******************************************************************************
* FILE NAME: user_routines_fast.c
*
* DESCRIPTION:
*  This file contains the interrupt handler code & the autonomous control routine
*
*******************************************************************************/

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"
#include "stdio.h"

#include "auto_routines.h"

/*** DEFINE USER VARIABLES AND INITIALIZE THEM HERE ***/

#pragma code InterruptVectorLow = LOW_INT_VECTOR
void InterruptVectorLow (void)
{
  _asm
    goto InterruptHandlerLow  /*jump to interrupt routine*/
  _endasm
}

#pragma code
#pragma interruptlow InterruptHandlerLow save=PROD /* You may want to save additional symbols. */

void InterruptHandlerLow ()     
{                               
  unsigned char int_byte; 
  
  if (INTCON3bits.INT2IF)         /* The INT2 pin is RB2/INTERRUPTS 1. (rc_dig_int1) */
  { 
    INTCON3bits.INT2IF = 0;
  }
  else if (INTCON3bits.INT3IF)    /* The INT3 pin is RB3/INTERRUPTS 2. (rc_dig_int2) */
  {
    INTCON3bits.INT3IF = 0;
  }
  else if (INTCONbits.RBIF)       /* INTERRUPTS 3-4 (RB4, RB5, RB6, or RB7) changed. */
  {
    int_byte = PORTB;             /* You must read or write to PORTB   */
    INTCONbits.RBIF = 0;          /* and clear the interrupt flag      */
  }                               /* to clear the interrupt condition. */
  else if ( (INTCONbits.TMR0IE) && (INTCONbits.TMR0IF) )
  {
    INTCONbits.TMR0IF = 0;
  }
  else if ( (PIE1bits.TMR2IE) && (PIR1bits.TMR2IF) )
  {
    PIR1bits.TMR2IF = 0;
  }
}

void User_Autonomous_Code(void)
{
  /* Initialize all PWMs and Relays when entering Autonomous mode, or else it
     will be stuck with the last values mapped from the joysticks.  Remember, 
     even when Disabled it is reading inputs from the Operator Interface. 
  */
  pwm01 = pwm02 = pwm03 = pwm04 = 127;
  pwm05 = pwm06 = pwm07 = pwm08 = 127;
  pwm09 = pwm10 = pwm11 = pwm12 = 127;

  while (autonomous_mode)   /* DO NOT CHANGE! */
  {
    if (statusflag.NEW_SPI_DATA)      /* 26.2ms loop area */
    {
      Getdata(&rxdata);   /* DO NOT DELETE, or you will be stuck here forever! */

      //Auto_Distance(); // Maintain a constant distance from a wall or object
      Sample_Auto_1a();

      if (ONBOARD_SWITCH == 0)
      {
        txdata.user_cmd |= 0x02;  // Tell Master we want to be in autonomous mode
      }
      else
     {
        txdata.user_cmd = 0;
      }

      Putdata(&txdata);   /* DO NOT DELETE, or you will get no PWM outputs! */
    }
  }
}


void Process_Data_From_Local_IO(void)
{
  /* Add code here that you want to be executed every program loop. */
}


/******************************************************************************/
/******************************************************************************/
/******************************************************************************/
